<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>

<xsl:template match="/">
       <xsl:call-template name="header"/>

    <!--section-01 (FREE)-->

    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (GRID)-->
    <xsl:call-template name="grid-open"/>
    <xsl:for-each select="//section-02">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-02">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-02"/>
    </xsl:for-each>
    <xsl:call-template name="signature"/>
</xsl:template>


    <!-- START DATA -->

<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Overdue Items'"/>
    </xsl:call-template>
</xsl:template>


<!--SECTION-01  (FREE)-->

<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="patron-address"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'salutation_string'"/>
    </xsl:call-template>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'The following item/s is/are overdue: ## ## '"/>
    </xsl:call-template>
</xsl:template>

    <!--SECTION-02  (GRID)-->

<xsl:template name="section-02">

  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid"/>
  </xsl:if>
<xsl:call-template name="table-start-row"/>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'#'"/>
       <xsl:with-param name="value" select="position()"/>
       <xsl:with-param name="type" select="'right'"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Bib Info'"/>
       <xsl:with-param name="value" select="./bib-info"/>
       <xsl:with-param name="type" select="'bib-info'"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Loan Date'"/>
       <xsl:with-param name="value" select="./z36-loan-date"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Loan Hour'"/>
       <xsl:with-param name="value" select="./z36-loan-hour"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Due Date'"/>
       <xsl:with-param name="value" select="./z36-due-date"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Due Hour'"/>
       <xsl:with-param name="value" select="./z36-due-hour"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Requested?'"/>
       <xsl:with-param name="value" select="./hold-status"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Recalled?'"/>
       <xsl:with-param name="value" select="./recall-status"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Notice No.'"/>
       <xsl:with-param name="value" select="./z36-letter-number"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Fine'"/>
       <xsl:with-param name="value" select="./fine-1"/>
       <xsl:with-param name="type" select="'right'"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Daily Fine'"/>
       <xsl:with-param name="value" select="./fine-2"/>
       <xsl:with-param name="type" select="'right'"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Hourly Fine'"/>
       <xsl:with-param name="value" select="./fine-3"/>
       <xsl:with-param name="type" select="'right'"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Barcode'"/>
       <xsl:with-param name="value" select="./z30-barcode"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Sublibrary'"/>
       <xsl:with-param name="value" select="./z30-sub-library"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Collection'"/>
       <xsl:with-param name="value" select="./z30-collection"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'Item Status'"/>
       <xsl:with-param name="value" select="./z30-item-status"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
<xsl:call-template name="table-end-row"/>
</xsl:template>
<xsl:template name="signature">
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'####Sincerely,##Circulation Department'"/>
    </xsl:call-template>
</xsl:template>
</xsl:stylesheet>



