<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
       <xsl:call-template name="header"/>


    <!--section-01 (SPLIT)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (GRID)-->
    <xsl:for-each select="//section-02">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-02">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-03 (FREE)-->
    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03"/>
    </xsl:for-each>

    <xsl:call-template name="signature"/>
</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Acquisition Order Slip'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (SPLIT)-->
<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="vendor-address"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'salutation_string##We would like to place an order for the following items:'"/>
    </xsl:call-template>
    <xsl:call-template name="salutation-end"/>
    <xsl:call-template name="bib-info-hdr"/>
    <xsl:call-template name="table-split-open"/>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Order Number:'"/>
       <xsl:with-param name="value" select="./z68-order-number"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Vendor Ref. No:'"/>
       <xsl:with-param name="value" select="./z68-vendor-reference-no"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'No. of Items:'"/>
       <xsl:with-param name="value" select="./z68-no-units"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Quantity Note:'"/>
       <xsl:with-param name="value" select="./z68-quantity-text"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Subs. start date:'"/>
       <xsl:with-param name="value" select="./z68-subscription-date-from"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Subs. end date:'"/>
       <xsl:with-param name="value" select="./z68-subscription-date-to"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Note:'"/>
       <xsl:with-param name="value" select="./z68-vendor-note"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Sublibrary:'"/>
       <xsl:with-param name="value" select="./z68-sub-library"/>
    </xsl:call-template>
    <xsl:call-template name="table-split-right"/>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Order Date:'"/>
       <xsl:with-param name="value" select="./z68-order-date"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Claim Date:'"/>
       <xsl:with-param name="value" select="./z68-eda"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Rush:'"/>
       <xsl:with-param name="value" select="./z68-rush"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Unit Price:'"/>
       <xsl:with-param name="value" select="./z68-unit-price"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Total Price:'"/>
       <xsl:with-param name="value" select="./z68-total-price"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Currency:'"/>
       <xsl:with-param name="value" select="./z68-e-currency"/>
    </xsl:call-template>
    <xsl:call-template name="table-split-close"/>
    <xsl:call-template name="directly-to-patron"/>
</xsl:template>

    <!--SECTION-02  (GRID)-->

<xsl:template name="section-02">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid"/>
  </xsl:if>
   <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Trans. Type:'"/>
          <xsl:with-param name="value" select="./z601-type"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Budget Number:'"/>
          <xsl:with-param name="value" select="./z601-budget-number"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Open Date:'"/>
          <xsl:with-param name="value" select="./z601-open-date"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Currency:'"/>
          <xsl:with-param name="value" select="./z601-currency"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Original Sum:'"/>
          <xsl:with-param name="value" select="./z601-original-sum"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Local Sum:'"/>
          <xsl:with-param name="value" select="./z601-local-sum"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   <xsl:call-template name="table-end-row"/>
</xsl:template>
<!--SECTION-03  (FREE)-->
<xsl:template name="section-03">
</xsl:template>
   <xsl:template name="signature">
       <xsl:call-template name="generic-line">
          <xsl:with-param name="line" select="'####Sincerely,
##Acquisition Department
'"/>
       </xsl:call-template>
   </xsl:template>
</xsl:stylesheet>


