<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
    <xsl:call-template name="header"/>

    <!--section-01 (FREE)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-05 (GRID)-->
    <xsl:for-each select="//section-05">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-05">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-05"/>
    </xsl:for-each>
    <xsl:call-template name="grid-close"/>

    <!--section-09 (FREE)-->
    <xsl:for-each select="//section-09">
       <xsl:call-template name="section-09"/>
    </xsl:for-each>


</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'General Retrieval Form for ADAM records'"/>
    </xsl:call-template>
</xsl:template>

    <!--SECTION-01  (FREE)-->

<xsl:template name="section-01">
    <xsl:call-template name="table-open"/>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Active Library:'"/>
          <xsl:with-param name="value" select="./active-library"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Sorted By:'"/>
          <xsl:with-param name="value" select="./sorted-by"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Out-file with selected Z403-REC-KEYs:'"/>
          <xsl:with-param name="value" select="./key-z403-file-out"/>
       </xsl:call-template>

       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Futher selection of file:'"/>
          <xsl:with-param name="value" select="./key-z403-file-in"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Validate objects file existence:'"/>
          <xsl:with-param name="value" select="./check-objects"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Identify duplicates:'"/>
          <xsl:with-param name="value" select="./check-duplicates"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- with using extension:'"/>
          <xsl:with-param name="value" select="./use-extension"/>
       </xsl:call-template>
    <xsl:call-template name="table-close"/>

    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'Parameters used as filters'"/>
       <xsl:with-param name="style" select="'underlined'"/>
    </xsl:call-template>

    <xsl:call-template name="table-open"/>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Doc-number from-to:'"/>
          <xsl:with-param name="value" select="concat(./doc-number-from,'-',./doc-number-to)"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- and using doc-number file:'"/>
          <xsl:with-param name="value" select="./doc-number-file-in"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Cataloger:'"/>
          <xsl:with-param name="value" select="./cataloger"/>
       </xsl:call-template>
       <xsl:variable name="vartest">
         <xsl:value-of select="./open-date-from"/>
       </xsl:variable>
       <xsl:if test="$vartest != ''">
          <xsl:call-template name="display-gen">
             <xsl:with-param name="label" select="'Open-date from-to:'"/>
             <xsl:with-param name="value" select="concat(./open-date-from,'-',./open-date-to)"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:variable name="vartest">
         <xsl:value-of select="./update-date-from"/>
       </xsl:variable>
       <xsl:if test="$vartest != ''">
          <xsl:call-template name="display-gen">
             <xsl:with-param name="label" select="'Update-date from-to:'"/>
             <xsl:with-param name="value" select="concat(./update-date-from,'-',./update-date-to)"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Expiry-date (to):'"/>
          <xsl:with-param name="value" select="./expiry-date"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Usage type:'"/>
          <xsl:with-param name="value" select="./usage-type"/>
       </xsl:call-template>

       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Free field-1:'"/>
          <xsl:with-param name="value" select="./field-1-name"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- using filing routine:'"/>
          <xsl:with-param name="value" select="./field-1-filing"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- using truncation:'"/>
          <xsl:with-param name="value" select="./field-1-truncate"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- compare with text-1:'"/>
          <xsl:with-param name="value" select="./field-1-text-1"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- compare with text-2:'"/>
          <xsl:with-param name="value" select="./field-1-text-2"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- compare with text-3:'"/>
          <xsl:with-param name="value" select="./field-1-text-3"/>
       </xsl:call-template>

       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Boolean operator between field-1 field-2:'"/>
          <xsl:with-param name="value" select="./field-1-op-field-2"/>
       </xsl:call-template>

       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Free field-2:'"/>
          <xsl:with-param name="value" select="./field-2-name"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- using filing routine:'"/>
          <xsl:with-param name="value" select="./field-2-filing"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- using truncation:'"/>
          <xsl:with-param name="value" select="./field-2-truncate"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- compare with text-2:'"/>
          <xsl:with-param name="value" select="./field-2-text-1"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- compare with text-2:'"/>
          <xsl:with-param name="value" select="./field-2-text-2"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- compare with text-3:'"/>
          <xsl:with-param name="value" select="./field-2-text-3"/>
       </xsl:call-template>

    <xsl:call-template name="table-close"/>
</xsl:template>

    <!--SECTION-05  (GRID)-->

<xsl:template name="section-05">
    <xsl:param name="header"/>
    <xsl:if test="$header!=''">
       <xsl:call-template name="start-grid"/>
    </xsl:if>
    <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Z403 Record Key'"/>
          <xsl:with-param name="value" select="concat(./z403-doc-number,' ', ./z403-sequence)"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Usage Type'"/>
          <xsl:with-param name="value" select="./z403-usage-type"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Directory'"/>
          <xsl:with-param name="value" select="./z403-f-directory"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Name'"/>
          <xsl:with-param name="value" select="./z403-f-filename"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Path'"/>
          <xsl:with-param name="value" select="./z403-u-path"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Title'"/>
          <xsl:with-param name="value" select="./z403-title"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
    <xsl:call-template name="table-end-row"/>
</xsl:template>

    <!--SECTION-09  (FREE)-->

<xsl:template name="section-09">
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="horizontal-line"/>
    <xsl:call-template name="horizontal-line"/>
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="table-open"/>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Retrieved:'"/>
          <xsl:with-param name="value" select="./cnt-z403-read"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Errors:'"/>
          <xsl:with-param name="value" select="./cnt-error"/>
       </xsl:call-template>
    <xsl:call-template name="table-close"/>
    <xsl:call-template name="horizontal-line"/>
</xsl:template>

</xsl:stylesheet>

