<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>

<xsl:template match="/">
    <xsl:call-template name="header"/>

    <!--section-01 (FREE)-->
    <xsl:for-each select="//section-01">
        <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (GRID)-->
    <xsl:for-each select="//section-02">
        <xsl:if test="position() = 1">
            <xsl:call-template name="section-02">
                <xsl:with-param name="header" select="'header'"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-03 (GRID)-->
    <xsl:for-each select="//section-03">
        <xsl:if test="position() = 1">
            <xsl:call-template name="section-03">
                <xsl:with-param name="header" select="'header'"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:call-template name="section-03"/>
    </xsl:for-each>

    <!--section-04 (FREE)-->
    <xsl:for-each select="//section-04">
        <xsl:call-template name="section-04"/>
    </xsl:for-each>

</xsl:template>


<!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
        <xsl:with-param name="title" select="'Advanced Library Statistics'"/>
    </xsl:call-template>
    <xsl:call-template name="generic-line">
        <xsl:with-param name="line" select="'Expenditures'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (FREE)-->
<xsl:template name="section-01">
    <xsl:call-template name="blank-line-first"/>
    <xsl:call-template name="table-open"/>
        <xsl:call-template name="display-gen">
            <xsl:with-param name="label" select="'Date From:'"/>
            <xsl:with-param name="value" select="./date-from"/>
        </xsl:call-template>
        <xsl:call-template name="display-gen">
            <xsl:with-param name="label" select="'Date To:'"/>
            <xsl:with-param name="value" select="./date-to"/>
        </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>

<!--SECTION-02  (GRID)-->
<xsl:template name="section-02">
    <xsl:param name="header"/>
    <xsl:if test="$header!=''">
        <xsl:call-template name="start-grid"/>
    </xsl:if>
    <xsl:call-template name="table-start-row"/>
    <xsl:call-template name="display-grid-gen">
        <xsl:with-param name="label" select="'Sub-library'"/>
        <xsl:with-param name="value" select="./sub-lib"/>
        <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
        <xsl:with-param name="label" select="'Expendit. in total'"/>
        <xsl:with-param name="value" select="./cash-all"/>
        <xsl:with-param name="type" select="'right'"/>
        <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
        <xsl:with-param name="label" select="'Electr. media'"/>
        <xsl:with-param name="value" select="./cash-e-medium"/>
        <xsl:with-param name="type" select="'right'"/>
        <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="table-end-row"/>
</xsl:template>

<!--SECTION-03 (GRID)-->
<xsl:template name="section-03">
    <xsl:param name="header"/>
    <xsl:call-template name="blank-line-first"/>
    <xsl:if test="$header!=''">
        <xsl:call-template name="start-grid"/>
    </xsl:if>
    <xsl:call-template name="table-start-row"/>
    <xsl:call-template name="display-grid-gen">
        <xsl:with-param name="label" select="'Budget-type'"/>
        <xsl:with-param name="value" select="./bind-trans"/>
        <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
        <xsl:with-param name="label" select="'Thereof for bindings'"/>
        <xsl:with-param name="value" select="./bind-cash"/>
        <xsl:with-param name="type" select="'right'"/>
        <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="table-end-row"/>
</xsl:template>

<!--SECTION-04  (FREE)-->
<xsl:template name="section-04">
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
        <xsl:with-param name="label" select="'Expenditure in total:'"/>
        <xsl:with-param name="value" select="./all-a"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
        <xsl:with-param name="label" select="'thereof for bindings:'"/>
        <xsl:with-param name="value" select="./all-b"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>
</xsl:stylesheet>

