<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
       <xsl:call-template name="header"/>

    <!--section-01 (FREE)-->

    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (FREE)-->

    <xsl:for-each select="//section-02">
       <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-06 (GRID)-->

    <xsl:for-each select="//section-06">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-06">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-06"/>
    </xsl:for-each>

    <!--section-03 (FREE)-->

    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03"/>
    </xsl:for-each>

    <!--section-05 (GRID)-->

    <xsl:for-each select="//section-05">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-05">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-05"/>
    </xsl:for-each>


    <!--section-07 (GRID)-->

    <xsl:for-each select="//section-07">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-07">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-07"/>
    </xsl:for-each>

</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Invoice Report (special)'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (FREE)-->

<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Approval Number:'"/>
       <xsl:with-param name="value" select="./approval-number"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Vendor Code:'"/>
       <xsl:with-param name="value" select="./z70-vendor-code"/>
       <xsl:with-param name="display" select="'always'"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Vendor Additional Code:'"/>
       <xsl:with-param name="value" select="./z70-additional-vendor-code"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Payment Address:'"/>
       <xsl:with-param name="value" select="''"/>
       <xsl:with-param name="display" select="'always'"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
    <xsl:call-template name="vendor-address"/>
</xsl:template>


<!--SECTION-02  (FREE)-->

<xsl:template name="section-02">
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Approval Dept:'"/>
       <xsl:with-param name="value" select="./z77-approval-department"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Invoice Number:'"/>
       <xsl:with-param name="value" select="./z77-invoice-number"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Invoice Date:'"/>
       <xsl:with-param name="value" select="./z77-i-date"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Invoice Currency:'"/>
       <xsl:with-param name="value" select="./z77-i-currency"/>
       <xsl:with-param name="display" select="'always'"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>



    <!--SECTION-05  (GRID)-->

<xsl:template name="section-05">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid">
         <xsl:with-param name="grid-title" select="'Division of VAT per vendor:'"/>
   </xsl:call-template>
  </xsl:if>
   <tr>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Vat Receiver'"/>
          <xsl:with-param name="value" select="./vat-receiver"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Vat Amount'"/>
          <xsl:with-param name="value" select="./vat-amount"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   </tr>
</xsl:template>


    <!--SECTION-06  (GRID)-->

<xsl:template name="section-06">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid">
         <xsl:with-param name="grid-title" select="'Budgets and Object code:'"/>
   </xsl:call-template>
  </xsl:if>
   <tr>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Budget Code'"/>
          <xsl:with-param name="value" select="./budget-number-2"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'External Name'"/>
          <xsl:with-param name="value" select="./z76-external-budget"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Code'"/>
          <xsl:with-param name="value" select="./budget-obj-code-2"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Budget Sum'"/>
          <xsl:with-param name="value" select="./budget-sum-2"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Budget Local Sum'"/>
          <xsl:with-param name="value" select="./budget-local-sum-2"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   </tr>
</xsl:template>

<!--SECTION-03  (FREE)-->

<xsl:template name="section-03">
    <xsl:call-template name="grid-title">
       <xsl:with-param name="grid-title" select="'Total sum:'"/>
    </xsl:call-template>
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Total Sum:'"/>
       <xsl:with-param name="value" select="./total-sum"/>
       <xsl:with-param name="display" select="'always'"/>
       <xsl:with-param name="type" select="'right'"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Total Sum Vat:'"/>
       <xsl:with-param name="value" select="./total-sum-vat"/>
       <xsl:with-param name="display" select="'always'"/>
       <xsl:with-param name="type" select="'right'"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Total Sum Net:'"/>
       <xsl:with-param name="value" select="./total-sum-net"/>
       <xsl:with-param name="display" select="'always'"/>
       <xsl:with-param name="type" select="'right'"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>


    <!--SECTION-07  (GRID)-->

<xsl:template name="section-07">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid">
         <xsl:with-param name="grid-title" select="'Non balanced debit items:'"/>
   </xsl:call-template>
  </xsl:if>
   <tr>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Invoice Number'"/>
          <xsl:with-param name="value" select="./z75-invoice-number"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Line Number'"/>
          <xsl:with-param name="value" select="./z75-line-number"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Total Amount'"/>
          <xsl:with-param name="value" select="./z75-i-total-amount"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   </tr>
</xsl:template>


</xsl:stylesheet>



