<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
       <xsl:call-template name="header"/>


    <!--section-01 (SPLIT)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (GRID)-->
    <xsl:for-each select="//section-02">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-02">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-03 (FREE)-->
    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03"/>
    </xsl:for-each>

    <xsl:call-template name="signature"/>
</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'采访取消信-mail'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (SPLIT)-->
<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="vendor-address"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'salutation_string##我们将取消下列订单:'"/>
    </xsl:call-template>
    <xsl:call-template name="salutation-end"/>
    <xsl:call-template name="bib-info-hdr"/>
    <xsl:call-template name="table-split-open"/>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'订单号:'"/>
       <xsl:with-param name="value" select="./z68-order-number"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'书商参考号:'"/>
       <xsl:with-param name="value" select="./z68-vendor-reference-no"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'册数:'"/>
       <xsl:with-param name="value" select="./z68-no-units"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'数量注释:'"/>
       <xsl:with-param name="value" select="./z68-quantity-text"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'预订起始日期:'"/>
       <xsl:with-param name="value" select="./z68-subscription-date-from"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'预订截止日期:'"/>
       <xsl:with-param name="value" select="./z68-subscription-date-to"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'注释:'"/>
       <xsl:with-param name="value" select="./z68-vendor-note"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'分馆:'"/>
       <xsl:with-param name="value" select="./z68-sub-library"/>
    </xsl:call-template>
    <xsl:call-template name="table-split-right"/>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'订单日期:'"/>
       <xsl:with-param name="value" select="./z68-order-date"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'催询日期:'"/>
       <xsl:with-param name="value" select="./z68-eda"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'加急:'"/>
       <xsl:with-param name="value" select="./z68-rush"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'单价:'"/>
       <xsl:with-param name="value" select="./z68-unit-price"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'总价:'"/>
       <xsl:with-param name="value" select="./z68-total-price"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'货币:'"/>
       <xsl:with-param name="value" select="./z68-e-currency"/>
    </xsl:call-template>
    <xsl:call-template name="table-split-close"/>
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'直接传送给:'"/>
       <xsl:with-param name="value" select="''"/>
       <xsl:with-param name="display" select="'always'"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
    <xsl:call-template name="patron-address"/>
</xsl:template>

    <!--SECTION-02  (GRID)-->

<xsl:template name="section-02">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid"/>
  </xsl:if>
   <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'事务类型:'"/>
          <xsl:with-param name="value" select="./z601-type"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'预算号:'"/>
          <xsl:with-param name="value" select="./z601-budget-number"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'打开日期:'"/>
          <xsl:with-param name="value" select="./z601-open-date"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'货币:'"/>
          <xsl:with-param name="value" select="./z601-currency"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'原始总额:'"/>
          <xsl:with-param name="value" select="./z601-original-sum"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'活动金额:'"/>
          <xsl:with-param name="value" select="./z601-active-sum"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'本地金额:'"/>
          <xsl:with-param name="value" select="./z601-local-sum"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   <xsl:call-template name="table-end-row"/>
</xsl:template>
<!--SECTION-03  (FREE)-->
<xsl:template name="section-03">
</xsl:template>
   <xsl:template name="signature">
       <xsl:call-template name="generic-line">
          <xsl:with-param name="line" select="'####采访部
'"/>
       </xsl:call-template>
   </xsl:template>
</xsl:stylesheet>


