<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="plain-funcs.xsl"/>

<xsl:template match="/">
       <xsl:call-template name="header"/>

    <!--section-01 (FREE)-->

    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
       <xsl:call-template name="new-line"/>
    </xsl:for-each>

    <!--section-02 (GRID)-->
    <xsl:call-template name="grid-open"/>
    <xsl:for-each select="//section-02">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-02">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
          <xsl:call-template name="new-line"/>
       </xsl:if>
       <xsl:call-template name="section-02"/>
       <xsl:call-template name="new-line"/>
    </xsl:for-each>
    <xsl:call-template name="signature"/>
</xsl:template>


    <!-- START DATA -->

<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'读者过期单册'"/>
    </xsl:call-template>
</xsl:template>


<!--SECTION-01  (FREE)-->

<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="patron-address"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'salutation_string'"/>
    </xsl:call-template>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'以下单册已经过期: '"/>
    </xsl:call-template>
</xsl:template>

    <!--SECTION-02  (GRID)-->

<xsl:template name="section-02">

  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid"/>
  </xsl:if>
<xsl:call-template name="table-start-row"/>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'书目信息'"/>
       <xsl:with-param name="value" select="./bib-info"/>
       <xsl:with-param name="type" select="'bib-info'"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'外借日期'"/>
       <xsl:with-param name="value" select="./z36-loan-date"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'外借时间'"/>
       <xsl:with-param name="value" select="./z36-loan-hour"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'应还日期'"/>
       <xsl:with-param name="value" select="./z36-due-date"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'应还时间'"/>
       <xsl:with-param name="value" select="./z36-due-hour"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'条码'"/>
       <xsl:with-param name="value" select="./z30-barcode"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'单册状态'"/>
       <xsl:with-param name="value" select="./z30-item-status"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'分馆'"/>
       <xsl:with-param name="value" select="./z30-sub-library"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'馆藏地'"/>
       <xsl:with-param name="value" select="./z30-collection"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'通知次数'"/>
       <xsl:with-param name="value" select="./z36-letter-number"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'被请求?'"/>
       <xsl:with-param name="value" select="./hold-status"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
    <xsl:call-template name="display-grid-gen">
       <xsl:with-param name="label" select="'被催还?'"/>
       <xsl:with-param name="value" select="./recall-status"/>
       <xsl:with-param name="header" select="$header"/>
    </xsl:call-template>
<xsl:call-template name="table-end-row"/>
</xsl:template>
<xsl:template name="signature">
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'流通部'"/>
    </xsl:call-template>
</xsl:template>
</xsl:stylesheet>



