<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
    <xsl:call-template name="header"/>

    <!--section-01 (FREE)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-05 (GRID)-->
    <xsl:for-each select="//section-05">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-05">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-05"/>
    </xsl:for-each>
    <xsl:call-template name="grid-close"/>

    <!--section-09 (FREE)-->
    <xsl:for-each select="//section-09">
       <xsl:call-template name="section-09"/>
    </xsl:for-each>


</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Deletion of ADAM records'"/>
    </xsl:call-template>
</xsl:template>

    <!--SECTION-01  (FREE)-->

<xsl:template name="section-01">
    <xsl:call-template name="table-open"/>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Active Library:'"/>
          <xsl:with-param name="value" select="./active-library"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Save-file with deleted Z403-records:'"/>
          <xsl:with-param name="value" select="./del-z403-file-out"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'In-file with Z403-REC-KEYs for deletion:'"/>
          <xsl:with-param name="value" select="./key-z403-file-in"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- with deletion of object-files:'"/>
          <xsl:with-param name="value" select="./delete-objects"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Update database:'"/>
          <xsl:with-param name="value" select="./update-db"/>
       </xsl:call-template>
    <xsl:call-template name="table-close"/>

    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'Parameters used as filters'"/>
       <xsl:with-param name="style" select="'underlined'"/>
    </xsl:call-template>

    <xsl:call-template name="table-open"/>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Doc-number from-to:'"/>
          <xsl:with-param name="value" select="concat(./doc-number-from,'-',./doc-number-to)"/>
       </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>

    <!--SECTION-05  (GRID)-->

<xsl:template name="section-05">
    <xsl:param name="header"/>
    <xsl:if test="$header!=''">
       <xsl:call-template name="start-grid"/>
    </xsl:if>
    <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Z403 Record Key'"/>
          <xsl:with-param name="value" select="concat(./z403-doc-number,' ', ./z403-sequence)"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Usage Type'"/>
          <xsl:with-param name="value" select="./z403-usage-type"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Directory'"/>
          <xsl:with-param name="value" select="./z403-f-directory"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Name'"/>
          <xsl:with-param name="value" select="./z403-f-filename"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Path'"/>
          <xsl:with-param name="value" select="./z403-u-path"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Object Title'"/>
          <xsl:with-param name="value" select="./z403-title"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
    <xsl:call-template name="table-end-row"/>
</xsl:template>

    <!--SECTION-09  (FREE)-->

<xsl:template name="section-09">
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="horizontal-line"/>
    <xsl:call-template name="horizontal-line"/>
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="table-open"/>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Handeled Z403-records:'"/>
          <xsl:with-param name="value" select="./cnt-z403-handle-done"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- deleted Z403:'"/>
          <xsl:with-param name="value" select="./cnt-z403-del"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- deleted objects:'"/>
          <xsl:with-param name="value" select="./cnt-object-del"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- objects not found:'"/>
          <xsl:with-param name="value" select="./cnt-object-notfound"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- Z403 not deleted:'"/>
          <xsl:with-param name="value" select="./cnt-z403-nodel"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- Z403 not found:'"/>
          <xsl:with-param name="value" select="./cnt-z403-notfound"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- - - - - - - - - - - - -'"/>
          <xsl:with-param name="value" select="''"/>
          <xsl:with-param name="display" select="'always'"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Handeled related Z403-records:'"/>
          <xsl:with-param name="value" select="./cnt-rel-z403-handle-done"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- deleted rel.Z403:'"/>
          <xsl:with-param name="value" select="./cnt-rel-z403-del"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- deleted objects:'"/>
          <xsl:with-param name="value" select="./cnt-rel-object-del"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- objects not found:'"/>
          <xsl:with-param name="value" select="./cnt-rel-object-notfound"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'- Z403 not found:'"/>
          <xsl:with-param name="value" select="./cnt-rel-z403-notfound"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'-------------------------'"/>
          <xsl:with-param name="value" select="''"/>
          <xsl:with-param name="display" select="'always'"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Warnings:'"/>
          <xsl:with-param name="value" select="./cnt-warning"/>
       </xsl:call-template>
       <xsl:call-template name="display-gen">
          <xsl:with-param name="label" select="'Errors:'"/>
          <xsl:with-param name="value" select="./cnt-error"/>
       </xsl:call-template>
    <xsl:call-template name="table-close"/>
    <xsl:call-template name="horizontal-line"/>
</xsl:template>

</xsl:stylesheet>

