<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
       <xsl:call-template name="header"/>


    <!--section-01 (FREE)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (FREE)-->
    <xsl:for-each select="//section-02">
       <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-03 (GRID)-->
    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03">
           <xsl:with-param name="header" select="'header'"/>
       </xsl:call-template>
       <xsl:call-template name="section-03"/>
    </xsl:for-each>

    <!--section-04 (FREE)-->
    <xsl:for-each select="//section-04">
       <xsl:call-template name="section-04"/>
    </xsl:for-each>

    <xsl:call-template name="signature"/>
</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Auto Return Letter'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (FREE)-->
<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="patron-address"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select='"##salutation_string##We have loaned your previous loan to a new reader:"'/>
    </xsl:call-template>
    <xsl:call-template name="salutation-end"/>

</xsl:template>

<!--SECTION-02  (FREE)-->
<xsl:template name="section-02">
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select="'Current Borrower:'"/>
    </xsl:call-template>
    <xsl:value-of select="//y302-address-0"/>
    <xsl:call-template name="blank-line"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Patron ID'"/>
       <xsl:with-param name="value" select="//y302-id"/>
    </xsl:call-template>
</xsl:template>

    <!--SECTION-03  (GRID)-->

<xsl:template name="section-03">
  <xsl:param name="header"/>
  <xsl:if test="$header !='' ">
      <xsl:call-template name="bib-info-hdr"/>
  </xsl:if>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid"/>
  </xsl:if>
   <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Description'"/>
          <xsl:with-param name="value" select="./z30-description"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Due Date'"/>
          <xsl:with-param name="value" select="./z36-due-date"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Return Date'"/>
          <xsl:with-param name="value" select="./z36h-returned-date"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Barcode'"/>
          <xsl:with-param name="value" select="./z30-barcode"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Sublibrary'"/>
          <xsl:with-param name="value" select="./z30-sub-library"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Collection'"/>
          <xsl:with-param name="value" select="./z30-collection"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Call Number'"/>
          <xsl:with-param name="value" select="./z30-call-no"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Item Status'"/>
          <xsl:with-param name="value" select="./z30-item-status"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'BorrowerID'"/>
          <xsl:with-param name="value" select="./z36-id"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Fine'"/>
          <xsl:with-param name="value" select="./fine"/>
          <xsl:with-param name="type" select="'right'"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>

        <xsl:if test="$header ='' ">
           <xsl:call-template name="table-close"/>
           <xsl:call-template name="grid-close"/>
           <xsl:call-template name="blank-line"/>
           <xsl:call-template name="blank-line"/>
        </xsl:if>

</xsl:template>
<!--SECTION-04  (FREE)-->
<xsl:template name="section-04">
</xsl:template>
   <xsl:template name="signature">
       <xsl:call-template name="generic-line">
          <xsl:with-param name="line" select="'##Sincerely,####Circulation Department'"/>
       </xsl:call-template>
   </xsl:template>
</xsl:stylesheet>



