<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
       <xsl:call-template name="header"/>

    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03b"/>
    </xsl:for-each>

    <!--section-01 (FREE)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (GRID)-->
    <xsl:for-each select="//section-02">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-02">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-03 (FREE)-->
    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03"/>
    </xsl:for-each>


</xsl:template>


    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Photocopy Request Slip'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (FREE)-->
<xsl:template name="section-01">
    <xsl:call-template name="sublib-address"/>
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="table-close"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select='"Material requested:"'/>
    </xsl:call-template>
    <xsl:call-template name="bib-info-hdr"/>
</xsl:template>

    <!--SECTION-02  (GRID)-->

<xsl:template name="section-02">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid"/>
  </xsl:if>
   <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'On Loan'"/>
          <xsl:with-param name="type" select="'check'"/>
          <xsl:with-param name="value" select="./loan-exists"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Sublibrary'"/>
          <xsl:with-param name="value" select="./z30-sub-library"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Item Status'"/>
          <xsl:with-param name="value" select="./z30-item-status"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Collection'"/>
          <xsl:with-param name="value" select="./z30-collection"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Call Number'"/>
          <xsl:with-param name="value" select="./z30-call-no"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Description'"/>
          <xsl:with-param name="value" select="./z30-description"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   <xsl:call-template name="table-end-row"/>
</xsl:template>
<!--SECTION-03  (FREE)-->
<xsl:template name="section-03">
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select='"##For patron:"'/>
    </xsl:call-template>
    <xsl:call-template name="patron-address"/>
    <xsl:call-template name="generic-line">
       <xsl:with-param name="line" select='"##"'/>
    </xsl:call-template>
    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Note:'"/>
       <xsl:with-param name="value" select="./z38-note-1"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Status:'"/>
       <xsl:with-param name="value" select="./z305-bor-status"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Type:'"/>
       <xsl:with-param name="value" select="./z305-bor-type"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Notes:'"/>
       <xsl:with-param name="value" select="./z302-field-1"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Requested by:'"/>
       <xsl:with-param name="value" select="./z38-requester-id"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Request date:'"/>
       <xsl:with-param name="value" select="./z38-open-date"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Author:'"/>
       <xsl:with-param name="value" select="./z38-author"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Title:'"/>
       <xsl:with-param name="value" select="./z38-title"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Pages:'"/>
       <xsl:with-param name="value" select="./z38-pages"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>

<xsl:template name="section-03b">

    <xsl:call-template name="table-open"/>
    <xsl:call-template name="display-gen">
       <xsl:with-param name="label" select="'Slip Number:'"/>
       <xsl:with-param name="value" select="./z38-number"/>
       <xsl:with-param name="width" select="'15%'"/>
    </xsl:call-template>
    <xsl:call-template name="table-close"/>
</xsl:template>

</xsl:stylesheet>


