<xsl:stylesheet
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>

<xsl:include href="funcs.xsl"/>


<xsl:template match="/">
       <xsl:call-template name="header"/>

    <!--section-01 (SPLIT)-->
    <xsl:for-each select="//section-01">
       <xsl:call-template name="section-01"/>
    </xsl:for-each>

    <!--section-02 (SPLIT)-->
    <xsl:for-each select="//section-02">
       <xsl:call-template name="section-02"/>
    </xsl:for-each>

    <!--section-03 (SPLIT)-->
    <xsl:for-each select="//section-03">
       <xsl:call-template name="section-03"/>
    </xsl:for-each>

    <!--section-04 (GRID)-->
    <xsl:for-each select="//section-04">
       <xsl:if test="position() = 1">
          <xsl:call-template name="section-04">
             <xsl:with-param name="header" select="'header'"/>
          </xsl:call-template>
       </xsl:if>
       <xsl:call-template name="section-04"/>
    </xsl:for-each>

</xsl:template>

    <!-- START DATA -->
<xsl:template name="header">
    <xsl:call-template name="header-gen">
       <xsl:with-param name="title" select="'Invoice Information'"/>
    </xsl:call-template>
</xsl:template>

<!--SECTION-01  (SPLIT)-->
<xsl:template name="section-01">
  <xsl:call-template name="table-split-open"/>
  <xsl:call-template name="free-title">
       <xsl:with-param name="free-title" select="'General Invoice:'"/>
   </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Number:'"/>
       <xsl:with-param name="value" select="./z77-invoice-number"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Lines Amount Covers General Invoice Amount:'"/>
       <xsl:with-param name="value" select="./compare-gen-inv-lines"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'All Invoice Lines are Completely Budgeted:'"/>
       <xsl:with-param name="value" select="./full-budget-line-inv"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Total Amount:'"/>
       <xsl:with-param name="value" select="./z77-i-total-amount"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Lines Total Amount:'"/>
       <xsl:with-param name="value" select="./total-invoice-lines"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Currency:'"/>
       <xsl:with-param name="value" select="./z77-i-currency"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Type:'"/>
       <xsl:with-param name="value" select="./z77-i-type"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Status:'"/>
       <xsl:with-param name="value" select="./z77-i-status"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Invoice Date:'"/>
       <xsl:with-param name="value" select="./z77-i-date"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'VAT:'"/>
       <xsl:with-param name="value" select="./z77-vat-amount"/>
    </xsl:call-template>
  <xsl:call-template name="table-split-close"/>
</xsl:template>

    <!--SECTION-02  (SPLIT)-->

<xsl:template name="section-02">
  <xsl:call-template name="table-split-open"/>
  <xsl:call-template name="free-title">
       <xsl:with-param name="free-title" select="'Payment:'"/>
   </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Status:'"/>
       <xsl:with-param name="value" select="./payment-status"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Amount:'"/>
       <xsl:with-param name="value" select="./payment-amount"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Payment Date:'"/>
       <xsl:with-param name="value" select="./payment-date"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Check Number:'"/>
       <xsl:with-param name="value" select="./check-number"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Approval:'"/>
       <xsl:with-param name="value" select="./approval-number"/>
    </xsl:call-template>
  <xsl:call-template name="table-split-close"/>
</xsl:template>

    <!--SECTION-03  (SPLIT)-->

<xsl:template name="section-03">
  <xsl:call-template name="table-split-open"/>
  <xsl:call-template name="free-title">
       <xsl:with-param name="free-title" select="'Vendor'"/>
   </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Vendor Code:'"/>
       <xsl:with-param name="value" select="./z70-vendor-code"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Vendor Name:'"/>
       <xsl:with-param name="value" select="./z70-vendor-name"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Note:'"/>
       <xsl:with-param name="value" select="./z70-note"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Order Address:'"/>
       <xsl:with-param name="value" select="./z72-vendor-address-0"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="value" select="./z72-vendor-address-1"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="value" select="./z72-vendor-address-2"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="value" select="./z72-vendor-address-3"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="value" select="./z72-vendor-address-4"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Telephone:'"/>
       <xsl:with-param name="value" select="./z72-vendor-tel"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Email:'"/>
       <xsl:with-param name="value" select="./z72-vendor-em"/>
    </xsl:call-template>
    <xsl:call-template name="display-gen-split">
       <xsl:with-param name="label" select="'Fax:'"/>
       <xsl:with-param name="value" select="./z72-vendor-fax"/>
    </xsl:call-template>
  <xsl:call-template name="table-split-close"/>
</xsl:template>

    <!--SECTION-04  (GRID)-->

<xsl:template name="section-04">
  <xsl:param name="header"/>
  <xsl:if test="$header!=''">
   <xsl:call-template name="start-grid">
     <xsl:with-param name="grid-title" select="'Invoice Lines'"/>
   </xsl:call-template>
  </xsl:if>
   <xsl:call-template name="table-start-row"/>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Line Number '"/>
          <xsl:with-param name="value" select="./z75-line-number"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'BIB Information'"/>
          <xsl:with-param name="value" select="./bib-info"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Amount'"/>
          <xsl:with-param name="value" select="./z75-i-total-amount"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Currency'"/>
          <xsl:with-param name="value" select="./currency"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'VAT'"/>
          <xsl:with-param name="value" select="./z75-i-vat-amount"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Order Number'"/>
          <xsl:with-param name="value" select="./z68-order-number"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Order Status/Date'"/>
          <xsl:with-param name="value" select='concat(./z68-order-status,"-",./z68-order-status-date)'/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
       <xsl:call-template name="display-grid-gen">
          <xsl:with-param name="label" select="'Budget Covers Line'"/>
          <xsl:with-param name="value" select="./budget-line-inv"/>
          <xsl:with-param name="header" select="$header"/>
       </xsl:call-template>
   <xsl:call-template name="table-end-row"/>
</xsl:template>
</xsl:stylesheet>

